# -*- coding: utf-8 *-*
import logging
import json
import os
import pwd
import sys

if sys.version_info[0] >= 3:
    from . import config
    from .dynamodb import DynamoHandler
else:
    import config
    from dynamodb import DynamoHandler

logger = logging.getLogger(config.Appl)
logger.setLevel(logging.DEBUG)

handler = DynamoHandler.to(config.Table,
                           config.Region,
                           config.AccessKeyId,
                           config.SecretAccessKey)
logger.addHandler(handler)

def info(str, meta=None):
    if meta:
        d = {'meta': json.dumps({'Appl': config.Appl, 'User': pwd.getpwuid(os.getuid()).pw_name, 'Data': meta})}
    else:
        d = {'meta': json.dumps({'Appl': config.Appl, 'User': pwd.getpwuid(os.getuid()).pw_name})}
    logger.info(str, extra=d)

def debug(str, meta=None):
    if meta:
        d = {'meta': json.dumps({'Appl': config.Appl, 'User': pwd.getpwuid(os.getuid()).pw_name, 'Data': meta})}
    else:
        d = {'meta': json.dumps({'Appl': config.Appl, 'User': pwd.getpwuid(os.getuid()).pw_name})}
    logger.debug(str, extra=d)

def warning(str, meta=None):
    if meta:
        d = {'meta': json.dumps({'Appl': config.Appl, 'User': pwd.getpwuid(os.getuid()).pw_name, 'Data': meta})}
    else:
        d = {'meta': json.dumps({'Appl': config.Appl, 'User': pwd.getpwuid(os.getuid()).pw_name})}
    logger.warning(str, extra=d)

def error(str, meta=None):
    if meta:
        d = {'meta': json.dumps({'Appl': config.Appl, 'User': pwd.getpwuid(os.getuid()).pw_name, 'Data': meta})}
    else:
        d = {'meta': json.dumps({'Appl': config.Appl, 'User': pwd.getpwuid(os.getuid()).pw_name})}
    logger.error(str, extra=d)


# -*- coding: utf-8 *-*
import json
import os

def set(app, table, path):
    global AccessKeyId
    global SecretAccessKey
    global Region
    global LogLevel
    global Appl
    global Table
    Appl = app
    Table = table
    if os.environ.get('AWS_REGION'):
        AccessKeyId = os.environ.get('AWS_ACCESS_KEY')
        SecretAccessKey = os.environ.get('AWS_SECRET_KEY')
        Region = os.environ.get('AWS_REGION')
        LogLevel = os.environ.get('LOGLEVEL')
    elif os.environ.get('AWS_DEFAULT_REGION'):
        if os.environ.get('AWS_ACCESS_KEY_ID'):
            AccessKeyId = os.environ.get('AWS_ACCESS_KEY_ID')
        else:
            AccessKeyId = os.environ.get('AWS_ACCESS_KEY')
        if os.environ.get('AWS_SECRET_ACCESS_KEY'):
            SecretAccessKey = os.environ.get('AWS_SECRET_ACCESS_KEY')
        else: 
            SecretAccessKey = os.environ.get('AWS_SECRET_KEY')
        Region = os.environ.get('AWS_DEFAULT_REGION')
        LogLevel = os.environ.get('LOGLEVEL')
    else:
        f = os.path.join(os.path.dirname(path), 'config.json')
        with open(f, 'r') as file:
            data = file.read()
        config = json.loads(data)
        AccessKeyId = config['accessKeyId']
        SecretAccessKey = config['secretAccessKey']
        Region = config['region']
        LogLevel = config['logLevel']


# -*- coding: utf-8 *-*
import sys
import logging
import datetime
import boto3

if sys.version_info[0] >= 3:
    unicode = str

class DynamoFormatter(logging.Formatter):
    def format(self, record):
        data = record.__dict__.copy()
        if record.args:
            msg = record.msg % record.args
        else:
            msg = record.msg
        data.update(
            args=str([unicode(arg) for arg in record.args]),
            msg=str(msg)
        )
        if sys.version_info[0] >= 3:
            data = dict((k, v) for k, v in data.items() if v)
        else:
            data = dict((k, v) for k, v in data.iteritems() if v)
        if 'exc_info' in data and data['exc_info']:
            data['exc_info'] = self.formatException(data['exc_info'])
        return data

class DynamoHandler(logging.Handler):
    @classmethod
    def to(cls, table_name, aws_region, aws_access_key_id, aws_secret_access_key, level=logging.NOTSET):
        return cls(table_name, aws_region, aws_access_key_id, aws_secret_access_key, level)

    def __init__(self, table_name, aws_region, aws_access_key_id, aws_secret_access_key, level=logging.NOTSET):
        logging.Handler.__init__(self, level)
        #dynamodb = boto3.resource('dynamodb', aws_access_key_id=aws_access_key_id, aws_secret_access_key=aws_secret_access_key)
        dynamodb = boto3.resource('dynamodb')
        self.table = dynamodb.Table(table_name)
        self.formatter = DynamoFormatter()

    def emit(self, record):
        try:
            r = self.format(record)
            r['level'] = r['levelname']
            r['timestamp'] = str(datetime.datetime.now())[:23]
            del r['created']
            del r['msecs']
            del r['thread']
            del r['relativeCreated']
            del r['levelname']
            self.table.put_item(Item=r)
        except Exception as e:
            logging.error("Unable to save log record: %s", e.response, exc_info=True)


from distutils.core import setup
setup(
  name = 'pythloghlp',
  packages = ['pythloghlp'], # this must be the same as the name above
  version = '0.1.11',
  description = 'Python DynamoDB Log Helper',
  author = 'Gunder Biten',
  author_email = 'gunder.biten@gabcia.se',
  url = 'https://github.com/Immunovia-AB/PythLogHlp', # use the URL to the github repo
  download_url = 'https://github.com/Immunovia-AB/PythLogHlp/tarball/0.1', # I'll explain this in a second
  keywords = ['logging', 'DynamoDB'], # arbitrary keywords
  classifiers=[]
)